[Pkg-owncloud-commits] [owncloud-client] 11/219: Propagator: Set the chunk size to 20MB as requested by Matt.

Sandro Knauß hefee-guest at moszumanska.debian.org
Sat Oct 11 14:43:03 UTC 2014


This is an automated email from the git hooks/post-receive script.

hefee-guest pushed a commit to branch master
in repository owncloud-client.

commit d2e1489fe78b9056a07079235ccef507f7c2310e
Author: Klaas Freitag <freitag at owncloud.com>
Date:   Wed Aug 27 10:35:58 2014 +0200

    Propagator: Set the chunk size to 20MB as requested by Matt.
---
 src/mirall/propagator_qnam.cpp | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/src/mirall/propagator_qnam.cpp b/src/mirall/propagator_qnam.cpp
index 9f83725..3b88aaa 100644
--- a/src/mirall/propagator_qnam.cpp
+++ b/src/mirall/propagator_qnam.cpp
@@ -32,7 +32,7 @@ static qint64 chunkSize() {
     if (!chunkSize) {
         chunkSize = qgetenv("OWNCLOUD_CHUNK_SIZE").toUInt();
         if (chunkSize == 0) {
-            chunkSize = 10*1024*1024; // default to 10 MiB
+            chunkSize = 20*1024*1024; // default to 20 MiB
         }
     }
     return chunkSize;

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud-client.git



More information about the Pkg-owncloud-commits mailing list